@@ -6,7 +6,7 @@ import (
 	imagelisters "github.com/openshift/client-go/image/listers/image/v1"
 	templatelisters "github.com/openshift/client-go/template/listers/template/v1"
 
-	sampoplisters "github.com/openshift/cluster-samples-operator/pkg/generated/listers/samples/v1"
+	sampoplisters "github.com/openshift/client-go/samples/listers/samples/v1"
 )
 
 type Listers struct {
